@@ -38,14 +38,14 @@ int main(int argc, char **argv)
     QApplication application(argc, argv);
     KLocalizedString::setApplicationDomain("kapptemplate");
 
-    KAboutData about("kapptemplate", i18n("KAppTemplate"), "0.1", i18n("KAppTemplate is a KDE project template generator"), KAboutLicense::GPL, i18n("(C) 2008 Anne-Marie Mahfouf"), QString(), 0, "submit@bugs.kde.org");
+    KAboutData about("kapptemplate", i18n("KAppTemplate"), "0.1", i18n("KAppTemplate is a KDE project template generator"), KAboutLicense::GPL, i18n("(C) 2008 Anne-Marie Mahfouf"), QString(), QString(), "submit@bugs.kde.org");
     about.addAuthor(i18n("Anne-Marie Mahfouf"), QString(), "annma AT kde DOT org");
     about.addAuthor(i18n("Sean Wilson"), i18n("Icons from Oxygen Team icons"), "suseux AT googlemail DOT com");
 
     KAboutData::setApplicationData(about);
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kapptemplate")));
 
-    KAppTemplate appTemplate(0);
+    KAppTemplate appTemplate;
     QCommandLineParser parser;
     about.setupCommandLine(&parser);
 
